# Leg' los!

Willkommen bei OpenSesame. Wie kann ich Dir helfen?

<table><tr><td>

Beginne ein neues Experiment:<br />
%(templates)s

</td><td>

%(recent_experiments)s

</td></tr></table>

Hast Du Dir schon einmal überlegt OpenSesame zu unterstützen? Es geht einfach und schnell.

[Spende via PayPal](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=QEWKSAY4WMKRW){: .important-button}

Finde mehr heraus:

[Dokumentation lesen (Englisch)](http://osdoc.cogsci.nl){: .button}<br />
[Frage im Forum stellen (Englisch)](http://forum.cogsci.nl){: .button}<br />
